==> PyDynamic-2.2.0-py3-none-any.whl: PyDynamic/__init__.py <==
"""
.. seealso::

   - `initial project website <https://www.euramet.org/research-innovation/search
     -research-projects/details/project/standards-and-software-to-maximise-end-user
     -uptake-of-nmi-calibrations-of-dynamic-force-torque-and/>`_
   - `GitHub website <https://www.github.com/PTB-M4D/PyDynamic>`_
"""
__version__ = "2.2.0"

__all__ = [
    "LSFIR",
    "LSIIR",
    "fit_som",
    "FreqResp2RealImag",
    "GUM_DFT",
    "GUM_iDFT",
    "DFT_deconv",
    "DFT_multiply",
    "DFT2AmpPhase",
    "AmpPhase2DFT",
    "AmpPhase2Time",
    "Time2AmpPhase",
    "dwt",
    "wave_dec",
    "wave_dec_realtime",
    "inv_dwt",
    "wave_rec",
    "filter_design",
    "dwt_max_level",
    "FIRuncFilter",
    "IIRuncFilter",
    "IIR_get_initial_state",
    "ARMA",
    "MC",
    "SMC",
    "UMC",
    "UMC_generic",
    "interp1d_unc",
    "db",
    "grpdelay",
    "mapinside",
    "isstable",
    "kaiser_lowpass",
    "savitzky_golay",
    "impinvar",
    "sos_absphase",
    "sos_realimag",
    "sos_FreqResp",
    "sos_phys2filter",
    "shocklikeGaussian",
    "GaussianPulse",
    "squarepulse",
    "rect",
    "corr_noise",
    "sine",
    "multi_sine",
    "ARMA",
    "print_mat",
    "print_vec",
    "make_semiposdef",
    "FreqResp2RealImag",
    "make_equidistant",
    "trimOrPad",
    "progress_bar",
    "shift_uncertainty",
    "is_vector",
    "is_2d_matrix",
    "number_of_rows_equals_vector_dim",
    "real_imag_2_complex",
    "separate_real_imag_of_mc_samples",
    "separate_real_imag_of_vector",
    "complex_2_real_imag",
]

from .misc import *
from .model_estimation import *
from .uncertainty import *

==> PyDynamic-2.5.1-py3-none-any.whl: PyDynamic/__init__.py <==
"""
.. seealso::

   - `initial project website <https://www.euramet.org/research-innovation/search
     -research-projects/details/project/standards-and-software-to-maximise-end-user
     -uptake-of-nmi-calibrations-of-dynamic-force-torque-and/>`_
   - `GitHub website <https://www.github.com/PTB-M4D/PyDynamic>`_
"""

__version__ = "2.5.1"

__all__ = [
    "LSFIR",
    "LSIIR",
    "fit_som",
    "FreqResp2RealImag",
    "GUM_DFT",
    "GUM_iDFT",
    "DFT_deconv",
    "DFT_multiply",
    "DFT2AmpPhase",
    "AmpPhase2DFT",
    "AmpPhase2Time",
    "Time2AmpPhase",
    "dwt",
    "wave_dec",
    "wave_dec_realtime",
    "inv_dwt",
    "wave_rec",
    "filter_design",
    "dwt_max_level",
    "FIRuncFilter",
    "IIRuncFilter",
    "IIR_get_initial_state",
    "ARMA",
    "MC",
    "SMC",
    "UMC",
    "UMC_generic",
    "interp1d_unc",
    "db",
    "grpdelay",
    "mapinside",
    "isstable",
    "kaiser_lowpass",
    "savitzky_golay",
    "impinvar",
    "sos_absphase",
    "sos_realimag",
    "sos_FreqResp",
    "sos_phys2filter",
    "shocklikeGaussian",
    "GaussianPulse",
    "squarepulse",
    "rect",
    "corr_noise",
    "sine",
    "multi_sine",
    "ARMA",
    "print_mat",
    "print_vec",
    "make_semiposdef",
    "FreqResp2RealImag",
    "make_equidistant",
    "trimOrPad",
    "progress_bar",
    "shift_uncertainty",
    "is_vector",
    "is_2d_matrix",
    "number_of_rows_equals_vector_dim",
    "real_imag_2_complex",
    "separate_real_imag_of_mc_samples",
    "separate_real_imag_of_vector",
    "complex_2_real_imag",
    "hadamar_product",
    "window_application",
]

import warnings

from .misc import *
from .model_estimation import *
from .uncertainty import *

warnings.warn(
    "This project is archived since May 2024. It will not receive any security "
    "related or other patches anymore and we cannot guarantee any form of support in "
    "the future.",
    DeprecationWarning,
    stacklevel=2,
)
